ParseError

Enum ParseError 

pub enum ParseError {
    NoCurrenciesDetected,
    MissingCount,
    MissingCurrencyName,
    UnexpectedToken {
        span: Range<usize>,
    },
    InvalidCurrencyName {
        span: Range<usize>,
    },
    ParseInt(ParseIntError),
    ParseFloat(ParseFloatError),
}
An error occurred parsing a currency from a string.

Variants



NoCurrenciesDetected

String was invalid.



MissingCount

A number was expected, but none was found.



MissingCurrencyName

A currency name was expected, but none was found.



UnexpectedToken

An unexpected element was found.

Fields

span: Range<usize>

The span of the unexpected token.



InvalidCurrencyName

An invalid currency name was found.

Fields

span: Range<usize>

The span of the invalid currency name.



ParseInt(ParseIntError)

A string failed to parse to an integer.



ParseFloat(ParseFloatError)

A string failed to parse to a float.